Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(51)

Unified Diff: tests/dartino_compiler/run.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/dartino_compiler/run.dart
diff --git a/tests/fletchc/run.dart b/tests/dartino_compiler/run.dart
similarity index 75%
rename from tests/fletchc/run.dart
rename to tests/dartino_compiler/run.dart
index 240ac433d948f2cea20d5569591c0b877881be4b..6a9aaed3566992a59720457c30cdf99dc4a90625 100644
--- a/tests/fletchc/run.dart
+++ b/tests/dartino_compiler/run.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.test.run;
+library dartino_compiler.test.run;
import 'dart:async';
@@ -10,15 +10,15 @@ import 'dart:io';
import 'dart:io' as io;
-import 'package:fletchc/src/hub/session_manager.dart';
+import 'package:dartino_compiler/src/hub/session_manager.dart';
-import 'package:fletchc/src/worker/developer.dart';
+import 'package:dartino_compiler/src/worker/developer.dart';
-import 'package:fletchc/src/worker/developer.dart' as developer;
+import 'package:dartino_compiler/src/worker/developer.dart' as developer;
-import 'package:fletchc/src/verbs/infrastructure.dart' show fileUri;
+import 'package:dartino_compiler/src/verbs/infrastructure.dart' show fileUri;
-import 'package:fletchc/src/device_type.dart' show
+import 'package:dartino_compiler/src/device_type.dart' show
DeviceType,
parseDeviceType;
@@ -30,17 +30,17 @@ const String userPackages = const String.fromEnvironment("packages");
const String userAgentAddress = const String.fromEnvironment("agent");
-const String fletchSettingsFile =
- const String.fromEnvironment("test.fletch_settings_file_name");
+const String dartinoSettingsFile =
+ const String.fromEnvironment("test.dartino_settings_file_name");
/// Enables printing of Compiler/VM protocol commands after each compilation.
const bool printCommands = const bool.fromEnvironment("printCommands");
/// Enables pretty printing the Fletch system (the compilation result) after
/// each compilation.
const bool printSystem = const bool.fromEnvironment("printSystem");
-class FletchRunner {
+class DartinoRunner {
Future<Null> attach(SessionState state) async {
if (userVmAddress == null) {
await startAndAttachDirectly(state, Uri.base);
@@ -51,8 +51,8 @@ class FletchRunner {
}
Future<Settings> computeSettings() async {
- if (fletchSettingsFile != null) {
- return await readSettings(fileUri(fletchSettingsFile, Uri.base));
+ if (dartinoSettingsFile != null) {
+ return await readSettings(fileUri(dartinoSettingsFile, Uri.base));
}
Address agentAddress =
userAgentAddress == null ? null : parseAddress(userAgentAddress);
@@ -101,9 +101,9 @@ class FletchRunner {
} else {
await developer.run(state);
}
- if (state.fletchVm != null) {
- int exitCode = await state.fletchVm.exitCode;
- print("$script: Fletch VM exit code: $exitCode");
+ if (state.dartinoVm != null) {
+ int exitCode = await state.dartinoVm.exitCode;
+ print("$script: Dartino VM exit code: $exitCode");
if (exitCode != expectedExitCode) {
return exitCode;
}
@@ -115,7 +115,7 @@ class FletchRunner {
}
main(List<String> arguments) async {
- io.exitCode = await new FletchRunner().run(arguments);
+ io.exitCode = await new DartinoRunner().run(arguments);
}
void checkExitCode(int expected, int actual) {
@@ -126,24 +126,24 @@ void checkExitCode(int expected, int actual) {
Future<Null> test() async {
checkExitCode(
- 0, await new FletchRunner().run(
+ 0, await new DartinoRunner().run(
<String>['tests/language/application_test.dart']));
}
Future<Null> testIncrementalDebugInfo() async {
checkExitCode(
- 0, await new FletchRunner().run(
- <String>['tests/fletchc/test_incremental_debug_info.dart',
- 'tests/fletchc/test_incremental_debug_info.dart'],
+ 0, await new DartinoRunner().run(
+ <String>['tests/dartino_compiler/test_incremental_debug_info.dart',
+ 'tests/dartino_compiler/test_incremental_debug_info.dart'],
expectedExitCode: 255));
}
// TODO(ahe): Move this method into FletchRunner and use computeSettings.
Future<Null> export(
String script, String snapshot, {bool binaryProgramInfo: false,
Map<String, String> constants: const <String, String> {}}) async {
Settings settings;
- if (fletchSettingsFile == null) {
+ if (dartinoSettingsFile == null) {
settings = new Settings(
fileUri(".packages", Uri.base),
<String>[],
@@ -152,7 +152,7 @@ Future<Null> export(
null,
IncrementalMode.none);
} else {
- settings = await readSettings(fileUri(fletchSettingsFile, Uri.base));
+ settings = await readSettings(fileUri(dartinoSettingsFile, Uri.base));
}
SessionState state = createSessionState("test", settings);
await compile(fileUri(script, Uri.base), state, Uri.base);
@@ -30,17 +30,17 @@ const String userPackages = const String.fromEnvironment("packages");
/// Enables printing of Compiler/VM protocol commands after each compilation.
const bool printCommands = const bool.fromEnvironment("printCommands");
-/// Enables pretty printing the Fletch system (the compilation result) after
+/// Enables pretty printing the Dartino system (the compilation result) after
/// each compilation.
const bool printSystem = const bool.fromEnvironment("printSystem");
@@ -126,24 +126,24 @@ void checkExitCode(int expected, int actual) {
expectedExitCode: 255));
}
-// TODO(ahe): Move this method into FletchRunner and use computeSettings.
+// TODO(ahe): Move this method into DartinoRunner and use computeSettings.
Future<Null> export(
String script, String snapshot, {bool binaryProgramInfo: false,
« no previous file with comments | « tests/dartino_compiler/incremental/tests_with_expectations.dart ('k') | tests/dartino_compiler/serialize_settings_tests.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698